@@ -3,9 +3,8 @@ from __future__ import print_function
 
 from collections.abc import Iterable
 import pytz
-import xpinyin
 from threading import Thread
-from chb._log import Log
+from chb._log import log
 from datetime import datetime
 
 import sys
@@ -16,7 +15,8 @@ try:
 except ImportError:
     pass
 from chb._imports import *
-log = Log(message_only=True)()
+# log = Log(message_only=True)()
+
 
 def set_device(cuda_index=0):
     """
